@@ -1,7 +1,7 @@
 #ifndef COMBINATORICS_H_
 #define COMBINATORICS_H_
 
-#include <types.h>
+#include "mytypes.h"
 
 void ksub_next ( int n, int k, IntVector& a, bool *more, int &m, int &m2);
 void comp_next ( int n, int k, IntVector& a, bool *more, int &h, int &t );
